Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PlayMusicWithReturn ¶
Types ¶
type MusicEntry ¶
type MusicEntry struct {
Id string // 编号
Name string // 歌名
Artist string // 作者
Source string // 位置
Type string // 类型
Filestream *os.File // 文件流
Format beep.Format // 文件信息
Streamer beep.StreamSeekCloser // 流信息
// contains filtered or unexported fields
}
func (*MusicEntry) Open ¶
func (me *MusicEntry) Open() error
func (*MusicEntry) Play ¶
func (me *MusicEntry) Play()
func (*MusicEntry) Stop ¶
func (me *MusicEntry) Stop()
Directories
¶
| Path | Synopsis |
|---|---|
|
effects
Package effects provides additional audio effects for the Beep library.
|
Package effects provides additional audio effects for the Beep library. |
|
flac
Package flac implements audio data decoding in FLAC format.
|
Package flac implements audio data decoding in FLAC format. |
|
mp3
Package mp3 implements audio data decoding in MP3 format.
|
Package mp3 implements audio data decoding in MP3 format. |
|
speaker
Package speaker implements playback of beep.Streamer values through physical speakers.
|
Package speaker implements playback of beep.Streamer values through physical speakers. |
|
vorbis
Package vorbis implements audio data decoding in oggvorbis format.
|
Package vorbis implements audio data decoding in oggvorbis format. |
|
wav
Package wav implements audio data decoding and encoding in WAVE format.
|
Package wav implements audio data decoding and encoding in WAVE format. |
|
Package oto offers io.Writer to play sound on multiple platforms.
|
Package oto offers io.Writer to play sound on multiple platforms. |
Click to show internal directories.
Click to hide internal directories.